#[derive(DefaultConstructor)]Expand description
Derive macro for generating a default constructor for structs.
Simply aliases the Default trait to provide a new method.
#[derive(DefaultConstructor)]Derive macro for generating a default constructor for structs.
Simply aliases the Default trait to provide a new method.